rebind_property_place

Function rebind_property_place 

fn rebind_property_place<'tcx>(property: &mut Property<'tcx>, local: Local)
Rebind every self place in a struct invariant to the given MIR local, so an invariant parsed against the struct’s own self can be asserted on a freshly-created reference (&*NonNull<T> → &T).